/// @file   output.h
/// @brief  Output routines for simulation of ants walking on a ruler.
/// @author Ramses van Zon
/// @date   2021
#ifndef OUTPUTH
#define OUTPUTH
#include <fstream>

/// @brief Function to write a vector a to an already opened binary file stream.
///
/// Write the nrows=1 and cols=a.size() in binary, and then the data of the rvector.
///
/// @param  file    an open file stream
/// @param  a       the rarray of integers
/// @param  margin  number of points to leave out at both ends 
///
/// @return void
///
void write_array_binary(std::ofstream &file, rvector<int> a, int margin);

/// @brief compute total, min and max of an rvector
///
/// @param  number_of_ants  rvector (input)
/// @param  nmin            minimum number in the array (output)
/// @param  nmax            maximum number in the array (output)
/// @param  total_ants      total number
///
/// @return void
///
void minmaxtot(rvector<int> number_of_ants, int& nmin, int& nmax, int& total_ants);

/// @brief Write numbers to screen
///
/// @param  stepnum     incremental step number (input)
/// @param  nmin        minimum number (input)
/// @param  nmax        minimum number (input)
/// @param  total_ants  total number (input)
/// 
/// @return void
///
void report(int stepnum, int nmin, int nmax, int total_ants);

#endif
