/// @file parameters.cpp

#include "parameters.h"
#include <cstring>
#include <iostream>
#include <fstream>

/// @brief Return a set of default parameters
Parameters default_parameters()
{
    Parameters result;
    result.length = 70;
    result.ntimesteps = 10000;
    result.outputinterval = 1000;
    result.totalants = 40000;
    result.seed = 120;
strncpy(result.antsfilename, "ants.bin", MAXFILENAMELEN+1);
    return result;
}

/// @brief Read parameters from a file. Missing parameters are set to
///        default values using default_parameters.
Parameters read_parameters(const std::string& inifilename)
{
    Parameters result = default_parameters();
    std::ifstream infile(inifilename);
    std::string line;
    while (std::getline(infile, line)) {
        size_t equalsignpos = line.find('=');
        if (equalsignpos != std::string::npos) {
            std::string key = line.substr(0, equalsignpos);
            std::string value = line.substr(equalsignpos+1);
            if      (key == "length")         result.length = std::stoi(value);
            else if (key == "ntimesteps")     result.ntimesteps = std::stoi(value);
            else if (key == "outputinterval") result.outputinterval = std::stoi(value);
            else if (key == "totalants")      result.totalants = std::stod(value);
            else if (key == "seed")           result.seed = std::stol(value);
            else if (key == "antsfilename")   strncpy(result.antsfilename, value.c_str(), MAXFILENAMELEN+1);
        }
    }
    return result;
}

/// @brief Print parameters
void print_parameters(const Parameters& params)
{
    std::cout << " length=" << params.length;
    std::cout << " ntimesteps=" << params.ntimesteps;
    std::cout << " outputinterval=" << params.outputinterval;
    std::cout << " totalants=" << params.totalants;
    std::cout << " seed=" << params.seed;
    std::cout << " outputfilename=" << params.antsfilename;
    std::cout << std::endl;
}

