/// @file parameters.h
/// @brief defines a struct for the ants on table/ruler model.
#ifndef PARAMETERSH
#define PARAMETERSH

#include <string>

/// @brief struct for the simulation parameters of the Nagel-Schreckenberg model
const int MAXFILENAMELEN = 100;
struct Parameters {
    int    length;         ///< length of the table or ruler
    int    ntimesteps;     ///< number of time steps to take
    int    outputinterval; ///< per how many steps to write out
    int    totalants;      ///< initial number of ants
    long   seed;           ///< seed for random number generation
    char   antsfilename[MAXFILENAMELEN+1];  ///< output file name as a fixed-sized string
};

/// @brief Return a set of default parameters
///
/// @return Parameters struct with length=70, ntimesteps=10000,
///         outputinterval=1000, totalants=40000, seed=120,
///         antsfilename="ants.bin"
Parameters default_parameters();

/// @brief Read parameters from a file. Missing parameters are set to
///        default values using default_parameters.
///
/// @param  inifilename  file with parameters (in)
///
/// @return Parameters struct
Parameters read_parameters(const std::string& inifilename);

/// @brief Print parameters to console
///
/// @param Parameter struct to print out
///
/// @return void
void print_parameters(const Parameters& params);

#endif
