/// @file   randompartitioning.h
/// @brief  Randomly separate numbers into sets
/// @author Ramses van Zon
/// @date   2021
#ifndef RANDOMPARTITIONINGH
#define RANDOMPARTITIONINGH

#include <random>

/// @brief Function to randomly divide a number 'total' into a set of
///        'numdivision' numbers that add up to 'total'. Uses the C++
///        random library to generate the randomness.
///
/// @param  engine    of type mt19937, to produce random numbers
/// @param  total     number that is to be subdivided (input)
/// @param  nparts    number of partitions into which to divide 'total (input)
/// @param  nperpart  resulting number in each partition (output)
///
/// @return void
///
void rand_partition(std::mt19937& engine, int total, int nparts, int* nperpart);

#endif
