/// @file   singlestepp.cpp
/// @brief  Take one time step in the simulation of ants walking on a ruler.
/// @author Ramses van Zon
/// @date   2021

#include <random>
#include "singlestep.h"
#include "randompartitioning.h"

/// @brief Single time step
void singlestep(rvector<int> number_of_ants, rvector<int> new_number_of_ants, std::mt19937& engine) 
{
    const int length = std::min(number_of_ants.size(), new_number_of_ants.size()) - 2*nguards;

    // ants move to a new an auxiliary new 'ruler', empty this one first
    new_number_of_ants.fill(0);

    // now move ants into auxiliary ruler
    for (int i = 0; i < length; i++) {
        if (number_of_ants[nguards+i] > 0) {
            const int nmoves = 3;   // number of possible moves for an ant
            int partition[nmoves];  // to store how many ants move in each direction
            rand_partition(engine, number_of_ants[nguards+i], nmoves, partition);
            // push ants in their respective move directionsx
            for (int m = 0; m < nmoves; m++) {
                const int di = m - 1;  // (0=to the left 1=stay, 2=to the right)
                const int i2 = i + di;
                new_number_of_ants[nguards+i2] += partition[m];
            }
        }
    }
    
    // update number_of_ants
    for (int i = 0; i < length; i++) {
        number_of_ants[nguards+i] = new_number_of_ants[nguards+i];
    }
    // consider ants in guards cells to have fallen off the ruler
    for (int i = 0; i < nguards; i++) {
        number_of_ants[i] = 0;
        number_of_ants[length+2*nguards-1-i] = 0;
    }
    
}
