/// @file   singlestepp.h
/// @brief  Take one time step in the simulation of ants walking on a ruler.
/// @author Ramses van Zon
/// @date   2021
#ifndef SINGLESTEPH
#define SINGLESTEPH

#include <random>
#include <rarray>

const int nguards = 1; // use one guard cell on each end of the ruler 

/// @brief Take a single time step to move the ants on the ruler
/// 
/// @param  number_of_ants       rvector representing ants on ruler of size length
/// @param  new_number_of_ants   auxiliar 2d array of the same size as number_of_ants
/// @param  length               size of the ruler in each direction (input)
/// @param  engine               random number generator (in/out)
///
/// @return void
///
void singlestep(rvector<int> number_of_ants, rvector<int> new_number_of_ants, std::mt19937& engine);

#endif
